@@ -36,7 +36,7 @@ function(model,breaks=NULL,nc=NULL)
 #
   expected.1=rep(0,nc)
   for(j in 1:nc)
-    expected.1[j]=sum(predict(model,compute=TRUE,integrate=TRUE,int.range=c(breaks[j],breaks[j+1]))$fitted/model$fitted,na.rm=TRUE)   
+    expected.1[j]=sum(predict(model,compute=TRUE,integrate=TRUE,int.range=matrix(c(breaks[j],breaks[j+1]),nrow=1))$fitted/model$fitted,na.rm=TRUE)   
 #
 #   Compute observed values of distance bins
 #
