@@ -1,9 +1,9 @@
 integratelogistic <-
-function (x, models, beta, width, point) 
+function (x, models, beta, lower=0, width, point) 
 {
 #   integratelogistic - computes integral (numerically) over x from 0 to width of a 
 #     logistic detection function 
 #
-  integrate(logisticbyx,lower=0,upper=width, subdivisions=10, rel.tol=0.01,abs.tol=0.01,x=x,
+  integrate(logisticbyx,lower=lower,upper=width, subdivisions=10, rel.tol=0.01,abs.tol=0.01,x=x,
                        models=models, beta=beta, point=point)$value
 }
